[Scummvm-cvs-logs] SF.net SVN: scummvm:[46056] scummvm/trunk/engines/draci/animation.cpp

spalek at users.sourceforge.net spalek at users.sourceforge.net
Sun Nov 22 03:42:15 CET 2009


Revision: 46056
          http://scummvm.svn.sourceforge.net/scummvm/?rev=46056&view=rev
Author:   spalek
Date:     2009-11-22 02:42:15 +0000 (Sun, 22 Nov 2009)

Log Message:
-----------
Fixed Animation::getTopAnimation()

It does not return kTitleText and others.  This caused flickering of speech
texts on/off when the title got displayed under the mouse.

Modified Paths:
--------------
    scummvm/trunk/engines/draci/animation.cpp

Modified: scummvm/trunk/engines/draci/animation.cpp
===================================================================
--- scummvm/trunk/engines/draci/animation.cpp	2009-11-21 23:44:52 UTC (rev 46055)
+++ scummvm/trunk/engines/draci/animation.cpp	2009-11-22 02:42:15 UTC (rev 46056)
@@ -504,10 +504,12 @@
 			}
 		}
 
 		// Return the top-most animation object, unless it is an
 		// overlay sprite and there is an actual object underneath it.
 		if (matches) {
-			if (anim->getID() != kOverlayImage) {
+			if (anim->getID() > kOverlayImage || anim->getID() < kSpeechText) {
 				return anim;
 			} else if (retval == NULL) {
 				retval = anim;
@@ -504,10 +504,12 @@
 		}
 
-		// Return the top-most animation object, unless it is an
-		// overlay sprite and there is an actual object underneath it.
+		// Return the top-most animation object, unless it is a
+		// non-clickable sprite (overlay, debugging sprites for
+		// walking, or title/speech text) and there is an actual object
+		// underneath it.
 		if (matches) {


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list